% The idea of this script or eventually function is to create a mesh using
% the mesh2d functionality.  Then write all the data that we need to files
% so that they can be read into the fortran FEM code and we can solve a
% given problem.

function [] = DW_create_mesh2(h)

close all
clc

% Filenames
file_points = 'XY_points.csv';
file_indices = 'Nodes.csv';
file_Unk = 'Unknowns.csv';
file_H = 'H.txt';


%
node = [0,0;1,0;0,1]

% Get the number of points we have
[n,~] = size(node);

% Initialize edge
edge = zeros(n,2);

% The edges are continuous
for i = 1:n-1
    edge(i,1) = i;
    edge(i,2) = i+1;
end
edge(n,:) = [n,1];
   
edge

% Set the discretization
hdata.hmax = h;

% Create the mesh
% p is the list of xy nodal points we have
% t corresponds to the node indices and matches local to 
%   global nodes
[p,t] = mesh2d(node,edge,hdata);

% Set the axis
axis on
axis([0 max(node(:,1)) 0 max(node(:,2))]);

% Write the data to a comma seperated file so that we do
% not need to worry about whitespace and junk.
csvwrite(file_points,p);
csvwrite(file_indices,t);

% Also we need to write an unknown array using the nodes
% that we declared as boundaries
unk = zeros(size(p,1),1);
iunk = 1;
for i=1:size(p,1)
    
    flag = 0;
    
    % Need to look through all the edges to see if the point we are at is
    % on that edge
    for j=1:size(edge,1) 
        
       % The two points that define the edge
        ledge = [node(edge(j,2),1), node(edge(j,2),2), node(edge(j,1),1), node(edge(j,1),2)];
        
        % Check if they are equal on the boundaries
        if(isPointOnEdge(p(i,:),ledge))
            flag = 1;
            break;
        end
    end
    
    % If there is a flag then this point is on the boundary
    if(flag == 1)
        unk(i) = -1;
    else
        unk(i) = iunk;
        iunk = iunk + 1;
    end
end
unk
% And then write the unknown array to a file
csvwrite(file_Unk,unk);

% Write the discretization to the file
csvwrite(file_H,h);

% And now move everything to the fem code location
movefile(file_points,'..\\..\\FEM_code')
movefile(file_indices,'..\\..\\FEM_code')
movefile(file_Unk,'..\\..\\FEM_code')
movefile(file_H,'..\\..\\FEM_code')
    

